# groxai_llms
pip package for using different llms


Supports gpt and gemini


Ensure you have your openai and google api key as system path variables like:

OPENAI_API_KEY: <Your API KEY>
GOOGLE_API_KEY: <Your API KEY>